# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/solution_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/atlas/solution_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import solution_pb2 as eolymp_dot_atlas_dot_solution__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/atlas/solution_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1b\x65olymp/atlas/solution.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"\xde\x03\n\x12ListSolutionsInput\x12\x0f\n\x07version\x18\x64 \x01(\r\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06search\x18\x14 \x01(\t\x12\x38\n\x07\x66ilters\x18( \x01(\x0b\x32\'.eolymp.atlas.ListSolutionsInput.Filter\x12\x37\n\x04sort\x18\x32 \x01(\x0e\x32).eolymp.atlas.ListSolutionsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x1a\xc9\x01\n\x06\x46ilter\x12*\n\x02id\x18\n \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12.\n\x04type\x18\x0b \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x04name\x18\x0c \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x31\n\x07runtime\x18\r \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"\x1e\n\x08Sortable\x12\x08\n\x04NAME\x10\x00\x12\x08\n\x04TYPE\x10\x01\"K\n\x13ListSolutionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.atlas.Solution\"\x9c\x02\n\x13\x43heckSolutionsInput\x12\x39\n\x07\x66ilters\x18( \x01(\x0b\x32(.eolymp.atlas.CheckSolutionsInput.Filter\x1a\xc9\x01\n\x06\x46ilter\x12*\n\x02id\x18\n \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12.\n\x04type\x18\x0b \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x04name\x18\x0c \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x31\n\x07runtime\x18\r \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"\x16\n\x14\x43heckSolutionsOutput\"=\n\x15\x44\x65scribeSolutionInput\x12\x13\n\x0bsolution_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\"B\n\x16\x44\x65scribeSolutionOutput\x12(\n\x08solution\x18\x01 \x01(\x0b\x32\x16.eolymp.atlas.Solution\"?\n\x13\x43reateSolutionInput\x12(\n\x08solution\x18\x02 \x01(\x0b\x32\x16.eolymp.atlas.Solution\"+\n\x14\x43reateSolutionOutput\x12\x13\n\x0bsolution_id\x18\x01 \x01(\t\"\xd7\x01\n\x13UpdateSolutionInput\x12\x36\n\x05patch\x18\x01 \x03(\x0e\x32\'.eolymp.atlas.UpdateSolutionInput.Patch\x12\x13\n\x0bsolution_id\x18\x03 \x01(\t\x12(\n\x08solution\x18\x04 \x01(\x0b\x32\x16.eolymp.atlas.Solution\"I\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\x08\n\x04TYPE\x10\x02\x12\x0b\n\x07RUNTIME\x10\x03\x12\n\n\x06SOURCE\x10\x04\x12\n\n\x06SECRET\x10\x05\"\x16\n\x14UpdateSolutionOutput\"*\n\x13\x44\x65leteSolutionInput\x12\x13\n\x0bsolution_id\x18\x02 \x01(\t\"\x16\n\x14\x44\x65leteSolutionOutput2\xd1\x07\n\x0fSolutionService\x12\x95\x01\n\x0e\x43reateSolution\x12!.eolymp.atlas.CreateSolutionInput\x1a\".eolymp.atlas.CreateSolutionOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x0c\x1a\n/solutions\x12\xa3\x01\n\x0eUpdateSolution\x12!.eolymp.atlas.UpdateSolutionInput\x1a\".eolymp.atlas.UpdateSolutionOutput\"J\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x1a\x1a\x18/solutions/{solution_id}\x12\xa3\x01\n\x0e\x44\x65leteSolution\x12!.eolymp.atlas.DeleteSolutionInput\x1a\".eolymp.atlas.DeleteSolutionOutput\"J\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x1a*\x18/solutions/{solution_id}\x12\xa8\x01\n\x10\x44\x65scribeSolution\x12#.eolymp.atlas.DescribeSolutionInput\x1a$.eolymp.atlas.DescribeSolutionOutput\"I\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\x1a\x12\x18/solutions/{solution_id}\x12\x91\x01\n\rListSolutions\x12 .eolymp.atlas.ListSolutionsInput\x1a!.eolymp.atlas.ListSolutionsOutput\";\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\x0c\x12\n/solutions\x12\x9a\x01\n\x0e\x43heckSolutions\x12!.eolymp.atlas.CheckSolutionsInput\x1a\".eolymp.atlas.CheckSolutionsOutput\"A\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\x12\"\x10/solutions:checkB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.solution_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_SOLUTIONSERVICE'].methods_by_name['CreateSolution']._loaded_options = None
  _globals['_SOLUTIONSERVICE'].methods_by_name['CreateSolution']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\014\032\n/solutions'
  _globals['_SOLUTIONSERVICE'].methods_by_name['UpdateSolution']._loaded_options = None
  _globals['_SOLUTIONSERVICE'].methods_by_name['UpdateSolution']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\032\032\030/solutions/{solution_id}'
  _globals['_SOLUTIONSERVICE'].methods_by_name['DeleteSolution']._loaded_options = None
  _globals['_SOLUTIONSERVICE'].methods_by_name['DeleteSolution']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\032*\030/solutions/{solution_id}'
  _globals['_SOLUTIONSERVICE'].methods_by_name['DescribeSolution']._loaded_options = None
  _globals['_SOLUTIONSERVICE'].methods_by_name['DescribeSolution']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\032\022\030/solutions/{solution_id}'
  _globals['_SOLUTIONSERVICE'].methods_by_name['ListSolutions']._loaded_options = None
  _globals['_SOLUTIONSERVICE'].methods_by_name['ListSolutions']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\014\022\n/solutions'
  _globals['_SOLUTIONSERVICE'].methods_by_name['CheckSolutions']._loaded_options = None
  _globals['_SOLUTIONSERVICE'].methods_by_name['CheckSolutions']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\022\"\020/solutions:check'
  _globals['_LISTSOLUTIONSINPUT']._serialized_start=251
  _globals['_LISTSOLUTIONSINPUT']._serialized_end=729
  _globals['_LISTSOLUTIONSINPUT_FILTER']._serialized_start=496
  _globals['_LISTSOLUTIONSINPUT_FILTER']._serialized_end=697
  _globals['_LISTSOLUTIONSINPUT_SORTABLE']._serialized_start=699
  _globals['_LISTSOLUTIONSINPUT_SORTABLE']._serialized_end=729
  _globals['_LISTSOLUTIONSOUTPUT']._serialized_start=731
  _globals['_LISTSOLUTIONSOUTPUT']._serialized_end=806
  _globals['_CHECKSOLUTIONSINPUT']._serialized_start=809
  _globals['_CHECKSOLUTIONSINPUT']._serialized_end=1093
  _globals['_CHECKSOLUTIONSINPUT_FILTER']._serialized_start=496
  _globals['_CHECKSOLUTIONSINPUT_FILTER']._serialized_end=697
  _globals['_CHECKSOLUTIONSOUTPUT']._serialized_start=1095
  _globals['_CHECKSOLUTIONSOUTPUT']._serialized_end=1117
  _globals['_DESCRIBESOLUTIONINPUT']._serialized_start=1119
  _globals['_DESCRIBESOLUTIONINPUT']._serialized_end=1180
  _globals['_DESCRIBESOLUTIONOUTPUT']._serialized_start=1182
  _globals['_DESCRIBESOLUTIONOUTPUT']._serialized_end=1248
  _globals['_CREATESOLUTIONINPUT']._serialized_start=1250
  _globals['_CREATESOLUTIONINPUT']._serialized_end=1313
  _globals['_CREATESOLUTIONOUTPUT']._serialized_start=1315
  _globals['_CREATESOLUTIONOUTPUT']._serialized_end=1358
  _globals['_UPDATESOLUTIONINPUT']._serialized_start=1361
  _globals['_UPDATESOLUTIONINPUT']._serialized_end=1576
  _globals['_UPDATESOLUTIONINPUT_PATCH']._serialized_start=1503
  _globals['_UPDATESOLUTIONINPUT_PATCH']._serialized_end=1576
  _globals['_UPDATESOLUTIONOUTPUT']._serialized_start=1578
  _globals['_UPDATESOLUTIONOUTPUT']._serialized_end=1600
  _globals['_DELETESOLUTIONINPUT']._serialized_start=1602
  _globals['_DELETESOLUTIONINPUT']._serialized_end=1644
  _globals['_DELETESOLUTIONOUTPUT']._serialized_start=1646
  _globals['_DELETESOLUTIONOUTPUT']._serialized_end=1668
  _globals['_SOLUTIONSERVICE']._serialized_start=1671
  _globals['_SOLUTIONSERVICE']._serialized_end=2648
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Recipient(_message.Message):
    __slots__ = ("id", "created_at", "updated_at", "sent_at", "delivered_at", "member_id", "status", "status_reason", "parameters")
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_STATUS: _ClassVar[Recipient.Status]
        CREATED: _ClassVar[Recipient.Status]
        PENDING: _ClassVar[Recipient.Status]
        SENT: _ClassVar[Recipient.Status]
        DELIVERED: _ClassVar[Recipient.Status]
        BOUNCED: _ClassVar[Recipient.Status]
        SKIPPED: _ClassVar[Recipient.Status]
        ERROR: _ClassVar[Recipient.Status]
    UNKNOWN_STATUS: Recipient.Status
    CREATED: Recipient.Status
    PENDING: Recipient.Status
    SENT: Recipient.Status
    DELIVERED: Recipient.Status
    BOUNCED: Recipient.Status
    SKIPPED: Recipient.Status
    ERROR: Recipient.Status
    class ParametersEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    SENT_AT_FIELD_NUMBER: _ClassVar[int]
    DELIVERED_AT_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    STATUS_REASON_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    id: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    sent_at: _timestamp_pb2.Timestamp
    delivered_at: _timestamp_pb2.Timestamp
    member_id: str
    status: Recipient.Status
    status_reason: str
    parameters: _containers.ScalarMap[str, str]
    def __init__(self, id: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., sent_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., delivered_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., member_id: _Optional[str] = ..., status: _Optional[_Union[Recipient.Status, str]] = ..., status_reason: _Optional[str] = ..., parameters: _Optional[_Mapping[str, str]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class DescribeRuntimeConfigInput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeRuntimeConfigOutput(_message.Message):
    __slots__ = ("allowed_runtime",)
    ALLOWED_RUNTIME_FIELD_NUMBER: _ClassVar[int]
    allowed_runtime: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, allowed_runtime: _Optional[_Iterable[str]] = ...) -> None: ...

class ConfigureRuntimeConfigInput(_message.Message):
    __slots__ = ("allowed_runtime",)
    ALLOWED_RUNTIME_FIELD_NUMBER: _ClassVar[int]
    allowed_runtime: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, allowed_runtime: _Optional[_Iterable[str]] = ...) -> None: ...

class ConfigureRuntimeConfigOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/acl/policy.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/acl/policy.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.acl import action_pb2 as eolymp_dot_acl_dot_action__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x65olymp/acl/policy.proto\x12\neolymp.acl\x1a\x17\x65olymp/acl/action.proto\"~\n\x06Policy\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tprincipal\x18\x03 \x01(\t\x12\x10\n\x08resource\x18\n \x01(\t\x12\x11\n\tallow_all\x18\x0c \x01(\x08\x12\"\n\x06\x61llows\x18\x0b \x03(\x0e\x32\x12.eolymp.acl.ActionB)Z\'github.com/eolymp/go-sdk/eolymp/acl;aclb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.acl.policy_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\'github.com/eolymp/go-sdk/eolymp/acl;acl'
  _globals['_POLICY']._serialized_start=64
  _globals['_POLICY']._serialized_end=190
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.community import rating_point_pb2 as _rating_point_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetRatingInput(_message.Message):
    __slots__ = ("rating_id", "rating")
    RATING_ID_FIELD_NUMBER: _ClassVar[int]
    RATING_FIELD_NUMBER: _ClassVar[int]
    rating_id: str
    rating: _rating_point_pb2.RatingPoint
    def __init__(self, rating_id: _Optional[str] = ..., rating: _Optional[_Union[_rating_point_pb2.RatingPoint, _Mapping]] = ...) -> None: ...

class SetRatingOutput(_message.Message):
    __slots__ = ("rating_id",)
    RATING_ID_FIELD_NUMBER: _ClassVar[int]
    rating_id: str
    def __init__(self, rating_id: _Optional[str] = ...) -> None: ...

class DeleteRatingInput(_message.Message):
    __slots__ = ("rating_id", "point")
    RATING_ID_FIELD_NUMBER: _ClassVar[int]
    POINT_FIELD_NUMBER: _ClassVar[int]
    rating_id: str
    point: _rating_point_pb2.RatingPoint
    def __init__(self, rating_id: _Optional[str] = ..., point: _Optional[_Union[_rating_point_pb2.RatingPoint, _Mapping]] = ...) -> None: ...

class DeleteRatingOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/executor/generation_report.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/executor/generation_report.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import stats_pb2 as eolymp_dot_executor_dot_stats__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'eolymp/executor/generation_report.proto\x12\x0f\x65olymp.executor\x1a\x1b\x65olymp/executor/stats.proto\"\xe5\x04\n\x10GenerationReport\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x11\n\treference\x18\x02 \x01(\t\x12\x0e\n\x06origin\x18\x03 \x01(\t\x12\x41\n\x08metadata\x18\x05 \x03(\x0b\x32/.eolymp.executor.GenerationReport.MetadataEntry\x12\r\n\x05\x61gent\x18\x04 \x01(\t\x12\x33\n\x04runs\x18( \x03(\x0b\x32%.eolymp.executor.GenerationReport.Run\x12\x15\n\rerror_message\x18\x32 \x01(\t\x1a\xcd\x02\n\x03Run\x12\x11\n\treference\x18\x01 \x01(\t\x12<\n\x06status\x18\x02 \x01(\x0e\x32,.eolymp.executor.GenerationReport.Run.Status\x12\r\n\x05valid\x18\x1f \x01(\x08\x12\x11\n\tinput_url\x18\n \x01(\t\x12\x12\n\nanswer_url\x18\x0b \x01(\t\x12\x35\n\x15input_generator_stats\x18\x14 \x01(\x0b\x32\x16.eolymp.executor.Stats\x12\x36\n\x16\x61nswer_generator_stats\x18\x1e \x01(\x0b\x32\x16.eolymp.executor.Stats\x12\x15\n\rerror_message\x18( \x01(\t\"9\n\x06Status\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0c\n\x08\x43OMPLETE\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x33Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.generation_report_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _globals['_GENERATIONREPORT_METADATAENTRY']._loaded_options = None
  _globals['_GENERATIONREPORT_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_GENERATIONREPORT']._serialized_start=90
  _globals['_GENERATIONREPORT']._serialized_end=703
  _globals['_GENERATIONREPORT_RUN']._serialized_start=321
  _globals['_GENERATIONREPORT_RUN']._serialized_end=654
  _globals['_GENERATIONREPORT_RUN_STATUS']._serialized_start=597
  _globals['_GENERATIONREPORT_RUN_STATUS']._serialized_end=654
  _globals['_GENERATIONREPORT_METADATAENTRY']._serialized_start=656
  _globals['_GENERATIONREPORT_METADATAENTRY']._serialized_end=703
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.atlas import code_template_pb2 as _code_template_pb2
from eolymp.atlas import statement_pb2 as _statement_pb2
from eolymp.atlas import testing_test_pb2 as _testing_test_pb2
from eolymp.course import submission_service_pb2 as _submission_service_pb2
from eolymp.playground import run_pb2 as _run_pb2
from eolymp.runtime import runtime_pb2 as _runtime_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListStatementsInput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListStatementsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_statement_pb2.Statement]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_statement_pb2.Statement, _Mapping]]] = ...) -> None: ...

class LookupStatementInput(_message.Message):
    __slots__ = ("locale",)
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    locale: str
    def __init__(self, locale: _Optional[str] = ...) -> None: ...

class LookupStatementOutput(_message.Message):
    __slots__ = ("statement",)
    STATEMENT_FIELD_NUMBER: _ClassVar[int]
    statement: _statement_pb2.Statement
    def __init__(self, statement: _Optional[_Union[_statement_pb2.Statement, _Mapping]] = ...) -> None: ...

class ListExamplesInput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListExamplesOutput(_message.Message):
    __slots__ = ("examples",)
    EXAMPLES_FIELD_NUMBER: _ClassVar[int]
    examples: _containers.RepeatedCompositeFieldContainer[_testing_test_pb2.Test]
    def __init__(self, examples: _Optional[_Iterable[_Union[_testing_test_pb2.Test, _Mapping]]] = ...) -> None: ...

class LookupCodeTemplateInput(_message.Message):
    __slots__ = ("runtime",)
    RUNTIME_FIELD_NUMBER: _ClassVar[int]
    runtime: str
    def __init__(self, runtime: _Optional[str] = ...) -> None: ...

class LookupCodeTemplateOutput(_message.Message):
    __slots__ = ("template",)
    TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    template: _code_template_pb2.Template
    def __init__(self, template: _Optional[_Union[_code_template_pb2.Template, _Mapping]] = ...) -> None: ...

class CreateRunInput(_message.Message):
    __slots__ = ("runtime", "source", "input_data", "input_ref")
    RUNTIME_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    INPUT_DATA_FIELD_NUMBER: _ClassVar[int]
    INPUT_REF_FIELD_NUMBER: _ClassVar[int]
    runtime: str
    source: str
    input_data: bytes
    input_ref: str
    def __init__(self, runtime: _Optional[str] = ..., source: _Optional[str] = ..., input_data: _Optional[bytes] = ..., input_ref: _Optional[str] = ...) -> None: ...

class CreateRunOutput(_message.Message):
    __slots__ = ("run_id",)
    RUN_ID_FIELD_NUMBER: _ClassVar[int]
    run_id: str
    def __init__(self, run_id: _Optional[str] = ...) -> None: ...

class DescribeRunInput(_message.Message):
    __slots__ = ("run_id",)
    RUN_ID_FIELD_NUMBER: _ClassVar[int]
    run_id: str
    def __init__(self, run_id: _Optional[str] = ...) -> None: ...

class DescribeRunOutput(_message.Message):
    __slots__ = ("run",)
    RUN_FIELD_NUMBER: _ClassVar[int]
    run: _run_pb2.Run
    def __init__(self, run: _Optional[_Union[_run_pb2.Run, _Mapping]] = ...) -> None: ...

class WatchRunInput(_message.Message):
    __slots__ = ("run_id",)
    RUN_ID_FIELD_NUMBER: _ClassVar[int]
    run_id: str
    def __init__(self, run_id: _Optional[str] = ...) -> None: ...

class WatchRunOutput(_message.Message):
    __slots__ = ("run",)
    RUN_FIELD_NUMBER: _ClassVar[int]
    run: _run_pb2.Run
    def __init__(self, run: _Optional[_Union[_run_pb2.Run, _Mapping]] = ...) -> None: ...

class ListRuntimesInput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListRuntimesOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_runtime_pb2.Runtime]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_runtime_pb2.Runtime, _Mapping]]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.newsletter import campaign_pb2 as _campaign_pb2
from eolymp.newsletter import recipient_pb2 as _recipient_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateCampaignInput(_message.Message):
    __slots__ = ("campaign",)
    CAMPAIGN_FIELD_NUMBER: _ClassVar[int]
    campaign: _campaign_pb2.Campaign
    def __init__(self, campaign: _Optional[_Union[_campaign_pb2.Campaign, _Mapping]] = ...) -> None: ...

class CreateCampaignOutput(_message.Message):
    __slots__ = ("campaign_id",)
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    campaign_id: str
    def __init__(self, campaign_id: _Optional[str] = ...) -> None: ...

class UpdateCampaignInput(_message.Message):
    __slots__ = ("patch", "campaign_id", "campaign")
    PATCH_FIELD_NUMBER: _ClassVar[int]
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    CAMPAIGN_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[_campaign_pb2.Campaign.Patch]
    campaign_id: str
    campaign: _campaign_pb2.Campaign
    def __init__(self, patch: _Optional[_Iterable[_Union[_campaign_pb2.Campaign.Patch, str]]] = ..., campaign_id: _Optional[str] = ..., campaign: _Optional[_Union[_campaign_pb2.Campaign, _Mapping]] = ...) -> None: ...

class UpdateCampaignOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteCampaignInput(_message.Message):
    __slots__ = ("campaign_id",)
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    campaign_id: str
    def __init__(self, campaign_id: _Optional[str] = ...) -> None: ...

class DeleteCampaignOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeCampaignInput(_message.Message):
    __slots__ = ("campaign_id", "extra")
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    campaign_id: str
    extra: _containers.RepeatedScalarFieldContainer[_campaign_pb2.Campaign.Extra]
    def __init__(self, campaign_id: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_campaign_pb2.Campaign.Extra, str]]] = ...) -> None: ...

class DescribeCampaignOutput(_message.Message):
    __slots__ = ("campaign",)
    CAMPAIGN_FIELD_NUMBER: _ClassVar[int]
    campaign: _campaign_pb2.Campaign
    def __init__(self, campaign: _Optional[_Union[_campaign_pb2.Campaign, _Mapping]] = ...) -> None: ...

class ListCampaignsInput(_message.Message):
    __slots__ = ("offset", "size", "filters", "search", "sort", "order", "locale", "extra")
    class Sort(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        CREATED_AT: _ClassVar[ListCampaignsInput.Sort]
    CREATED_AT: ListCampaignsInput.Sort
    class Filter(_message.Message):
        __slots__ = ("id", "type")
        ID_FIELD_NUMBER: _ClassVar[int]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        type: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., type: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    filters: ListCampaignsInput.Filter
    search: str
    sort: ListCampaignsInput.Sort
    order: _direction_pb2.Direction
    locale: str
    extra: _containers.RepeatedScalarFieldContainer[_campaign_pb2.Campaign.Extra]
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListCampaignsInput.Filter, _Mapping]] = ..., search: _Optional[str] = ..., sort: _Optional[_Union[ListCampaignsInput.Sort, str]] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ..., locale: _Optional[str] = ..., extra: _Optional[_Iterable[_Union[_campaign_pb2.Campaign.Extra, str]]] = ...) -> None: ...

class ListCampaignsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_campaign_pb2.Campaign]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_campaign_pb2.Campaign, _Mapping]]] = ...) -> None: ...

class TestCampaignInput(_message.Message):
    __slots__ = ("campaign_id", "email", "locale", "member_id", "parameters")
    class ParametersEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    campaign_id: str
    email: str
    locale: str
    member_id: str
    parameters: _containers.ScalarMap[str, str]
    def __init__(self, campaign_id: _Optional[str] = ..., email: _Optional[str] = ..., locale: _Optional[str] = ..., member_id: _Optional[str] = ..., parameters: _Optional[_Mapping[str, str]] = ...) -> None: ...

class TestCampaignOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SendCampaignInput(_message.Message):
    __slots__ = ("campaign_id", "recipient_id")
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    RECIPIENT_ID_FIELD_NUMBER: _ClassVar[int]
    campaign_id: str
    recipient_id: str
    def __init__(self, campaign_id: _Optional[str] = ..., recipient_id: _Optional[str] = ...) -> None: ...

class SendCampaignOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class TranslateCampaignInput(_message.Message):
    __slots__ = ("campaign_id", "source", "target", "target_automatic", "override_manual")
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    TARGET_FIELD_NUMBER: _ClassVar[int]
    TARGET_AUTOMATIC_FIELD_NUMBER: _ClassVar[int]
    OVERRIDE_MANUAL_FIELD_NUMBER: _ClassVar[int]
    campaign_id: str
    source: str
    target: _containers.RepeatedScalarFieldContainer[str]
    target_automatic: bool
    override_manual: bool
    def __init__(self, campaign_id: _Optional[str] = ..., source: _Optional[str] = ..., target: _Optional[_Iterable[str]] = ..., target_automatic: bool = ..., override_manual: bool = ...) -> None: ...

class TranslateCampaignOutput(_message.Message):
    __slots__ = ("job_id",)
    JOB_ID_FIELD_NUMBER: _ClassVar[int]
    job_id: str
    def __init__(self, job_id: _Optional[str] = ...) -> None: ...

class CreateTranslationInput(_message.Message):
    __slots__ = ("campaign_id", "translation")
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_FIELD_NUMBER: _ClassVar[int]
    campaign_id: str
    translation: _campaign_pb2.Campaign.Translation
    def __init__(self, campaign_id: _Optional[str] = ..., translation: _Optional[_Union[_campaign_pb2.Campaign.Translation, _Mapping]] = ...) -> None: ...

class CreateTranslationOutput(_message.Message):
    __slots__ = ("translation_id",)
    TRANSLATION_ID_FIELD_NUMBER: _ClassVar[int]
    translation_id: str
    def __init__(self, translation_id: _Optional[str] = ...) -> None: ...

class UpdateTranslationInput(_message.Message):
    __slots__ = ("patch", "campaign_id", "translation_id", "translation")
    PATCH_FIELD_NUMBER: _ClassVar[int]
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[_campaign_pb2.Campaign.Patch]
    campaign_id: str
    translation_id: str
    translation: _campaign_pb2.Campaign.Translation
    def __init__(self, patch: _Optional[_Iterable[_Union[_campaign_pb2.Campaign.Patch, str]]] = ..., campaign_id: _Optional[str] = ..., translation_id: _Optional[str] = ..., translation: _Optional[_Union[_campaign_pb2.Campaign.Translation, _Mapping]] = ...) -> None: ...

class UpdateTranslationOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteTranslationInput(_message.Message):
    __slots__ = ("campaign_id", "translation_id")
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_ID_FIELD_NUMBER: _ClassVar[int]
    campaign_id: str
    translation_id: str
    def __init__(self, campaign_id: _Optional[str] = ..., translation_id: _Optional[str] = ...) -> None: ...

class DeleteTranslationOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeTranslationInput(_message.Message):
    __slots__ = ("campaign_id", "translation_id")
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_ID_FIELD_NUMBER: _ClassVar[int]
    campaign_id: str
    translation_id: str
    def __init__(self, campaign_id: _Optional[str] = ..., translation_id: _Optional[str] = ...) -> None: ...

class DescribeTranslationOutput(_message.Message):
    __slots__ = ("translation",)
    TRANSLATION_FIELD_NUMBER: _ClassVar[int]
    translation: _campaign_pb2.Campaign.Translation
    def __init__(self, translation: _Optional[_Union[_campaign_pb2.Campaign.Translation, _Mapping]] = ...) -> None: ...

class ListTranslationsInput(_message.Message):
    __slots__ = ("campaign_id", "offset", "size", "filters")
    class Filter(_message.Message):
        __slots__ = ("id", "locale")
        ID_FIELD_NUMBER: _ClassVar[int]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        locale: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., locale: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    campaign_id: str
    offset: int
    size: int
    filters: ListTranslationsInput.Filter
    def __init__(self, campaign_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListTranslationsInput.Filter, _Mapping]] = ...) -> None: ...

class ListTranslationsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_campaign_pb2.Campaign.Translation]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_campaign_pb2.Campaign.Translation, _Mapping]]] = ...) -> None: ...

class CreateRecipientInput(_message.Message):
    __slots__ = ("campaign_id", "member_id", "parameters")
    class ParametersEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    campaign_id: str
    member_id: str
    parameters: _containers.ScalarMap[str, str]
    def __init__(self, campaign_id: _Optional[str] = ..., member_id: _Optional[str] = ..., parameters: _Optional[_Mapping[str, str]] = ...) -> None: ...

class CreateRecipientOutput(_message.Message):
    __slots__ = ("recipient_id",)
    RECIPIENT_ID_FIELD_NUMBER: _ClassVar[int]
    recipient_id: str
    def __init__(self, recipient_id: _Optional[str] = ...) -> None: ...

class ImportRecipientInput(_message.Message):
    __slots__ = ("campaign_id", "all_members", "group_id", "contest_id", "parameters")
    class ParametersEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    ALL_MEMBERS_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    campaign_id: str
    all_members: bool
    group_id: str
    contest_id: str
    parameters: _containers.ScalarMap[str, str]
    def __init__(self, campaign_id: _Optional[str] = ..., all_members: bool = ..., group_id: _Optional[str] = ..., contest_id: _Optional[str] = ..., parameters: _Optional[_Mapping[str, str]] = ...) -> None: ...

class ImportRecipientOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteRecipientInput(_message.Message):
    __slots__ = ("campaign_id", "recipient_id")
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    RECIPIENT_ID_FIELD_NUMBER: _ClassVar[int]
    campaign_id: str
    recipient_id: str
    def __init__(self, campaign_id: _Optional[str] = ..., recipient_id: _Optional[str] = ...) -> None: ...

class DeleteRecipientOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListRecipientsInput(_message.Message):
    __slots__ = ("campaign_id", "offset", "size", "filters")
    class Filter(_message.Message):
        __slots__ = ("id", "status", "member_id")
        ID_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        status: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        member_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., status: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., member_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ...) -> None: ...
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    campaign_id: str
    offset: int
    size: int
    filters: ListRecipientsInput.Filter
    def __init__(self, campaign_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListRecipientsInput.Filter, _Mapping]] = ...) -> None: ...

class ListRecipientsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_recipient_pb2.Recipient]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_recipient_pb2.Recipient, _Mapping]]] = ...) -> None: ...

class DescribeRecipientInput(_message.Message):
    __slots__ = ("campaign_id", "recipient_id")
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    RECIPIENT_ID_FIELD_NUMBER: _ClassVar[int]
    campaign_id: str
    recipient_id: str
    def __init__(self, campaign_id: _Optional[str] = ..., recipient_id: _Optional[str] = ...) -> None: ...

class DescribeRecipientOutput(_message.Message):
    __slots__ = ("recipient",)
    RECIPIENT_FIELD_NUMBER: _ClassVar[int]
    recipient: _recipient_pb2.Recipient
    def __init__(self, recipient: _Optional[_Union[_recipient_pb2.Recipient, _Mapping]] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Session(_message.Message):
    __slots__ = ("id", "user_agent", "device", "location", "ip_address", "first_seen_at", "last_seen_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    USER_AGENT_FIELD_NUMBER: _ClassVar[int]
    DEVICE_FIELD_NUMBER: _ClassVar[int]
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    IP_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    FIRST_SEEN_AT_FIELD_NUMBER: _ClassVar[int]
    LAST_SEEN_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    user_agent: str
    device: str
    location: str
    ip_address: str
    first_seen_at: _timestamp_pb2.Timestamp
    last_seen_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., user_agent: _Optional[str] = ..., device: _Optional[str] = ..., location: _Optional[str] = ..., ip_address: _Optional[str] = ..., first_seen_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., last_seen_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/discussion/thread.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/discussion/thread.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/discussion/thread.proto\x12\x11\x65olymp.discussion\"f\n\x06Thread\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04vote\x18\x0c \x01(\x05\x12\x12\n\nvote_count\x18\n \x01(\x05\x12\x13\n\x0breply_count\x18\x0b \x01(\x05\x42\x37Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.thread_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _globals['_THREAD']._serialized_start=53
  _globals['_THREAD']._serialized_end=155
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/discussion/configuration_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/discussion/configuration_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.discussion import configuration_pb2 as eolymp_dot_discussion_dot_configuration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-eolymp/discussion/configuration_service.proto\x12\x11\x65olymp.discussion\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a%eolymp/discussion/configuration.proto\"\x1f\n\x1d\x44\x65scribeDiscussionConfigInput\"R\n\x1e\x44\x65scribeDiscussionConfigOutput\x12\x30\n\x06\x63onfig\x18\x01 \x01(\x0b\x32 .eolymp.discussion.Configuration\"\xf4\x01\n\x1bUpdateDiscussionConfigInput\x12\x30\n\x06\x63onfig\x18\x01 \x01(\x0b\x32 .eolymp.discussion.Configuration\"\xa2\x01\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x1c\n\x18MEMBERS_CAN_CREATE_POSTS\x10\x01\x12 \n\x1cMEMBERS_CAN_COMMENT_ON_POSTS\x10\x02\x12#\n\x1fMEMBERS_CAN_COMMENT_ON_PROBLEMS\x10\x03\x12\x13\n\x0fPOST_MODERATION\x10\x04\x12\x16\n\x12\x43OMMENT_MODERATION\x10\x05\"\x1e\n\x1cUpdateDiscussionConfigOutput2\xee\x02\n\x14\x43onfigurationService\x12\xac\x01\n\x18\x44\x65scribeDiscussionConfig\x12\x30.eolymp.discussion.DescribeDiscussionConfigInput\x1a\x31.eolymp.discussion.DescribeDiscussionConfigOutput\"+\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x16\x12\x14/configs/discussions\x12\xa6\x01\n\x16UpdateDiscussionConfig\x12..eolymp.discussion.UpdateDiscussionConfigInput\x1a/.eolymp.discussion.UpdateDiscussionConfigOutput\"+\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x16\x1a\x14/configs/discussionsB7Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.configuration_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['DescribeDiscussionConfig']._loaded_options = None
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['DescribeDiscussionConfig']._serialized_options = b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002\026\022\024/configs/discussions'
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['UpdateDiscussionConfig']._loaded_options = None
  _globals['_CONFIGURATIONSERVICE'].methods_by_name['UpdateDiscussionConfig']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\026\032\024/configs/discussions'
  _globals['_DESCRIBEDISCUSSIONCONFIGINPUT']._serialized_start=174
  _globals['_DESCRIBEDISCUSSIONCONFIGINPUT']._serialized_end=205
  _globals['_DESCRIBEDISCUSSIONCONFIGOUTPUT']._serialized_start=207
  _globals['_DESCRIBEDISCUSSIONCONFIGOUTPUT']._serialized_end=289
  _globals['_UPDATEDISCUSSIONCONFIGINPUT']._serialized_start=292
  _globals['_UPDATEDISCUSSIONCONFIGINPUT']._serialized_end=536
  _globals['_UPDATEDISCUSSIONCONFIGINPUT_PATCH']._serialized_start=374
  _globals['_UPDATEDISCUSSIONCONFIGINPUT_PATCH']._serialized_end=536
  _globals['_UPDATEDISCUSSIONCONFIGOUTPUT']._serialized_start=538
  _globals['_UPDATEDISCUSSIONCONFIGOUTPUT']._serialized_end=568
  _globals['_CONFIGURATIONSERVICE']._serialized_start=571
  _globals['_CONFIGURATIONSERVICE']._serialized_end=937
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/feed/entry.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/feed/entry.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.wellknown import link_pb2 as eolymp_dot_wellknown_dot_link__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x65olymp/feed/entry.proto\x12\x0b\x65olymp.feed\x1a\x1b\x65olymp/wellknown/link.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe2\x01\n\x05\x45ntry\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\nattributes\x18\n \x03(\x0b\x32\".eolymp.feed.Entry.AttributesEntry\x12%\n\x05links\x18\x14 \x03(\x0b\x32\x16.eolymp.wellknown.Link\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42+Z)github.com/eolymp/go-sdk/eolymp/feed;feedb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.feed.entry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/eolymp/go-sdk/eolymp/feed;feed'
  _globals['_ENTRY_ATTRIBUTESENTRY']._loaded_options = None
  _globals['_ENTRY_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_ENTRY']._serialized_start=103
  _globals['_ENTRY']._serialized_end=329
  _globals['_ENTRY_ATTRIBUTESENTRY']._serialized_start=280
  _globals['_ENTRY_ATTRIBUTESENTRY']._serialized_end=329
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.course import assignment_pb2 as _assignment_pb2
from eolymp.course import class_pb2 as _class_pb2
from eolymp.wellknown import direction_pb2 as _direction_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateClassInput(_message.Message):
    __slots__ = ()
    CLASS_FIELD_NUMBER: _ClassVar[int]
    def __init__(self, **kwargs) -> None: ...

class CreateClassOutput(_message.Message):
    __slots__ = ("class_id",)
    CLASS_ID_FIELD_NUMBER: _ClassVar[int]
    class_id: str
    def __init__(self, class_id: _Optional[str] = ...) -> None: ...

class UpdateClassInput(_message.Message):
    __slots__ = ("patch", "group_id")
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        ALL: _ClassVar[UpdateClassInput.Patch]
        INACTIVE: _ClassVar[UpdateClassInput.Patch]
        ASSIGN_ALL: _ClassVar[UpdateClassInput.Patch]
    ALL: UpdateClassInput.Patch
    INACTIVE: UpdateClassInput.Patch
    ASSIGN_ALL: UpdateClassInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    CLASS_FIELD_NUMBER: _ClassVar[int]
    patch: _containers.RepeatedScalarFieldContainer[UpdateClassInput.Patch]
    group_id: str
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateClassInput.Patch, str]]] = ..., group_id: _Optional[str] = ..., **kwargs) -> None: ...

class UpdateClassOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteClassInput(_message.Message):
    __slots__ = ("group_id",)
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    group_id: str
    def __init__(self, group_id: _Optional[str] = ...) -> None: ...

class DeleteClassOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeClassInput(_message.Message):
    __slots__ = ("group_id",)
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    group_id: str
    def __init__(self, group_id: _Optional[str] = ...) -> None: ...

class DescribeClassOutput(_message.Message):
    __slots__ = ()
    CLASS_FIELD_NUMBER: _ClassVar[int]
    def __init__(self, **kwargs) -> None: ...

class ListClassesInput(_message.Message):
    __slots__ = ("offset", "size", "search", "filters", "sort", "order")
    class Sortable(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        DEFAULT: _ClassVar[ListClassesInput.Sortable]
    DEFAULT: ListClassesInput.Sortable
    class Filter(_message.Message):
        __slots__ = ("id", "group_id", "member_id")
        ID_FIELD_NUMBER: _ClassVar[int]
        GROUP_ID_FIELD_NUMBER: _ClassVar[int]
        MEMBER_ID_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        group_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        member_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., group_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., member_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ...) -> None: ...
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    search: str
    filters: ListClassesInput.Filter
    sort: ListClassesInput.Sortable
    order: _direction_pb2.Direction
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., search: _Optional[str] = ..., filters: _Optional[_Union[ListClassesInput.Filter, _Mapping]] = ..., sort: _Optional[_Union[ListClassesInput.Sortable, str]] = ..., order: _Optional[_Union[_direction_pb2.Direction, str]] = ...) -> None: ...

class ListClassesOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_class_pb2.Class]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_class_pb2.Class, _Mapping]]] = ...) -> None: ...

class ListClassAssignmentsInput(_message.Message):
    __slots__ = ("group_id", "offset", "size", "search", "filters")
    class Filter(_message.Message):
        __slots__ = ("id", "module_id")
        ID_FIELD_NUMBER: _ClassVar[int]
        MODULE_ID_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        module_id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., module_id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ...) -> None: ...
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    group_id: str
    offset: int
    size: int
    search: str
    filters: ListClassAssignmentsInput.Filter
    def __init__(self, group_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., search: _Optional[str] = ..., filters: _Optional[_Union[ListClassAssignmentsInput.Filter, _Mapping]] = ...) -> None: ...

class ListClassAssignmentsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_assignment_pb2.Assignment]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_assignment_pb2.Assignment, _Mapping]]] = ...) -> None: ...

class UpdateClassAssignmentInput(_message.Message):
    __slots__ = ("group_id", "module_id", "start_after", "complete_before", "duration", "upsolve")
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    MODULE_ID_FIELD_NUMBER: _ClassVar[int]
    START_AFTER_FIELD_NUMBER: _ClassVar[int]
    COMPLETE_BEFORE_FIELD_NUMBER: _ClassVar[int]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    UPSOLVE_FIELD_NUMBER: _ClassVar[int]
    group_id: str
    module_id: str
    start_after: _timestamp_pb2.Timestamp
    complete_before: _timestamp_pb2.Timestamp
    duration: int
    upsolve: bool
    def __init__(self, group_id: _Optional[str] = ..., module_id: _Optional[str] = ..., start_after: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., complete_before: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., duration: _Optional[int] = ..., upsolve: bool = ...) -> None: ...

class UpdateClassAssignmentOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteClassAssignmentInput(_message.Message):
    __slots__ = ("group_id", "module_id")
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    MODULE_ID_FIELD_NUMBER: _ClassVar[int]
    group_id: str
    module_id: str
    def __init__(self, group_id: _Optional[str] = ..., module_id: _Optional[str] = ...) -> None: ...

class DeleteClassAssignmentOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/newsletter/campaign_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/newsletter/campaign_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.newsletter import campaign_pb2 as eolymp_dot_newsletter_dot_campaign__pb2
from eolymp.newsletter import recipient_pb2 as eolymp_dot_newsletter_dot_recipient__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(eolymp/newsletter/campaign_service.proto\x12\x11\x65olymp.newsletter\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a eolymp/newsletter/campaign.proto\x1a!eolymp/newsletter/recipient.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"D\n\x13\x43reateCampaignInput\x12-\n\x08\x63\x61mpaign\x18\x01 \x01(\x0b\x32\x1b.eolymp.newsletter.Campaign\"+\n\x14\x43reateCampaignOutput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\"\x8b\x01\n\x13UpdateCampaignInput\x12\x30\n\x05patch\x18\x01 \x03(\x0e\x32!.eolymp.newsletter.Campaign.Patch\x12\x13\n\x0b\x63\x61mpaign_id\x18\x02 \x01(\t\x12-\n\x08\x63\x61mpaign\x18\x03 \x01(\x0b\x32\x1b.eolymp.newsletter.Campaign\"\x16\n\x14UpdateCampaignOutput\"*\n\x13\x44\x65leteCampaignInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\"\x16\n\x14\x44\x65leteCampaignOutput\"_\n\x15\x44\x65scribeCampaignInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x31\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32!.eolymp.newsletter.Campaign.Extra\"G\n\x16\x44\x65scribeCampaignOutput\x12-\n\x08\x63\x61mpaign\x18\x01 \x01(\x0b\x32\x1b.eolymp.newsletter.Campaign\"\xa9\x03\n\x12ListCampaignsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12=\n\x07\x66ilters\x18( \x01(\x0b\x32,.eolymp.newsletter.ListCampaignsInput.Filter\x12\x0e\n\x06search\x18) \x01(\t\x12\x38\n\x04sort\x18\x32 \x01(\x0e\x32*.eolymp.newsletter.ListCampaignsInput.Sort\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12\x0f\n\x06locale\x18\xe2\x08 \x01(\t\x12\x31\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32!.eolymp.newsletter.Campaign.Extra\x1a\x64\n\x06\x46ilter\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12.\n\x04type\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"\x16\n\x04Sort\x12\x0e\n\nCREATED_AT\x10\x00\"P\n\x13ListCampaignsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12*\n\x05items\x18\x02 \x03(\x0b\x32\x1b.eolymp.newsletter.Campaign\"\xd7\x01\n\x11TestCampaignInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x03 \x01(\t\x12\x11\n\tmember_id\x18\x04 \x01(\t\x12H\n\nparameters\x18\x14 \x03(\x0b\x32\x34.eolymp.newsletter.TestCampaignInput.ParametersEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x14\n\x12TestCampaignOutput\">\n\x11SendCampaignInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x14\n\x0crecipient_id\x18\x02 \x01(\t\"\x14\n\x12SendCampaignOutput\"\x80\x01\n\x16TranslateCampaignInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0e\n\x06target\x18\x03 \x03(\t\x12\x18\n\x10target_automatic\x18\x04 \x01(\x08\x12\x17\n\x0foverride_manual\x18\x05 \x01(\x08\")\n\x17TranslateCampaignOutput\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"k\n\x16\x43reateTranslationInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12<\n\x0btranslation\x18\x02 \x01(\x0b\x32\'.eolymp.newsletter.Campaign.Translation\"1\n\x17\x43reateTranslationOutput\x12\x16\n\x0etranslation_id\x18\x01 \x01(\t\"\xb5\x01\n\x16UpdateTranslationInput\x12\x30\n\x05patch\x18\x01 \x03(\x0e\x32!.eolymp.newsletter.Campaign.Patch\x12\x13\n\x0b\x63\x61mpaign_id\x18\x02 \x01(\t\x12\x16\n\x0etranslation_id\x18\x03 \x01(\t\x12<\n\x0btranslation\x18\x04 \x01(\x0b\x32\'.eolymp.newsletter.Campaign.Translation\"\x19\n\x17UpdateTranslationOutput\"E\n\x16\x44\x65leteTranslationInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\"\x19\n\x17\x44\x65leteTranslationOutput\"G\n\x18\x44\x65scribeTranslationInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x16\n\x0etranslation_id\x18\x02 \x01(\t\"Y\n\x19\x44\x65scribeTranslationOutput\x12<\n\x0btranslation\x18\x01 \x01(\x0b\x32\'.eolymp.newsletter.Campaign.Translation\"\xf4\x01\n\x15ListTranslationsInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12@\n\x07\x66ilters\x18( \x01(\x0b\x32/.eolymp.newsletter.ListTranslationsInput.Filter\x1a\x66\n\x06\x46ilter\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06locale\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"_\n\x16ListTranslationsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x36\n\x05items\x18\x02 \x03(\x0b\x32\'.eolymp.newsletter.Campaign.Translation\"\xbe\x01\n\x14\x43reateRecipientInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x0b \x01(\t\x12K\n\nparameters\x18\x14 \x03(\x0b\x32\x37.eolymp.newsletter.CreateRecipientInput.ParametersEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x15\x43reateRecipientOutput\x12\x14\n\x0crecipient_id\x18\x01 \x01(\t\"\xf6\x01\n\x14ImportRecipientInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x15\n\x0b\x61ll_members\x18\n \x01(\x08H\x00\x12\x12\n\x08group_id\x18\x0b \x01(\tH\x00\x12\x14\n\ncontest_id\x18\x0c \x01(\tH\x00\x12K\n\nparameters\x18\x14 \x03(\x0b\x32\x37.eolymp.newsletter.ImportRecipientInput.ParametersEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x08\n\x06source\"\x17\n\x15ImportRecipientOutput\"A\n\x14\x44\x65leteRecipientInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x14\n\x0crecipient_id\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteRecipientOutput\"\xa4\x02\n\x13ListRecipientsInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12>\n\x07\x66ilters\x18( \x01(\x0b\x32-.eolymp.newsletter.ListRecipientsInput.Filter\x1a\x99\x01\n\x06\x46ilter\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06status\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x31\n\tmember_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"R\n\x14ListRecipientsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12+\n\x05items\x18\x02 \x03(\x0b\x32\x1c.eolymp.newsletter.Recipient\"C\n\x16\x44\x65scribeRecipientInput\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x14\n\x0crecipient_id\x18\x02 \x01(\t\"J\n\x17\x44\x65scribeRecipientOutput\x12/\n\trecipient\x18\x01 \x01(\x0b\x32\x1c.eolymp.newsletter.Recipient2\xc5\x1b\n\x0f\x43\x61mpaignService\x12\xa7\x01\n\x0e\x43reateCampaign\x12&.eolymp.newsletter.CreateCampaignInput\x1a\'.eolymp.newsletter.CreateCampaignOutput\"D\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x03\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x0c\"\n/campaigns\x12\xb5\x01\n\x0eUpdateCampaign\x12&.eolymp.newsletter.UpdateCampaignInput\x1a\'.eolymp.newsletter.UpdateCampaignOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\x05\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x1a\x1a\x18/campaigns/{campaign_id}\x12\xb5\x01\n\x0e\x44\x65leteCampaign\x12&.eolymp.newsletter.DeleteCampaignInput\x1a\'.eolymp.newsletter.DeleteCampaignOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x1a*\x18/campaigns/{campaign_id}\x12\x99\x01\n\x10\x44\x65scribeCampaign\x12(.eolymp.newsletter.DescribeCampaignInput\x1a).eolymp.newsletter.DescribeCampaignOutput\"0\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\x1a\x12\x18/campaigns/{campaign_id}\x12\x81\x01\n\rListCampaigns\x12%.eolymp.newsletter.ListCampaignsInput\x1a&.eolymp.newsletter.ListCampaignsOutput\"!\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0c\x12\n/campaigns\x12\xb4\x01\n\x0cTestCampaign\x12$.eolymp.newsletter.TestCampaignInput\x1a%.eolymp.newsletter.TestCampaignOutput\"W\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x02\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x1f\"\x1d/campaigns/{campaign_id}/test\x12\xb4\x01\n\x0cSendCampaign\x12$.eolymp.newsletter.SendCampaignInput\x1a%.eolymp.newsletter.SendCampaignOutput\"W\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x02\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x1f\"\x1d/campaigns/{campaign_id}/send\x12\xc8\x01\n\x11TranslateCampaign\x12).eolymp.newsletter.TranslateCampaignInput\x1a*.eolymp.newsletter.TranslateCampaignOutput\"\\\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x02\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02$\"\"/campaigns/{campaign_id}/translate\x12\xcb\x01\n\x11\x43reateTranslation\x12).eolymp.newsletter.CreateTranslationInput\x1a*.eolymp.newsletter.CreateTranslationOutput\"_\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\'\"%/campaigns/{campaign_id}/translations\x12\xdc\x01\n\x11UpdateTranslation\x12).eolymp.newsletter.UpdateTranslationInput\x1a*.eolymp.newsletter.UpdateTranslationOutput\"p\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x38\x1a\x36/campaigns/{campaign_id}/translations/{translation_id}\x12\xdc\x01\n\x11\x44\x65leteTranslation\x12).eolymp.newsletter.DeleteTranslationInput\x1a*.eolymp.newsletter.DeleteTranslationOutput\"p\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x38*6/campaigns/{campaign_id}/translations/{translation_id}\x12\xe2\x01\n\x13\x44\x65scribeTranslation\x12+.eolymp.newsletter.DescribeTranslationInput\x1a,.eolymp.newsletter.DescribeTranslationOutput\"p\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xe3\n\x1e\x8a\xe3\n\x1anewsletter:newsletter:read\x82\xd3\xe4\x93\x02\x38\x12\x36/campaigns/{campaign_id}/translations/{translation_id}\x12\xc7\x01\n\x10ListTranslations\x12(.eolymp.newsletter.ListTranslationsInput\x1a).eolymp.newsletter.ListTranslationsOutput\"^\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x1e\x8a\xe3\n\x1anewsletter:newsletter:read\x82\xd3\xe4\x93\x02\'\x12%/campaigns/{campaign_id}/translations\x12\xc3\x01\n\x0f\x43reateRecipient\x12\'.eolymp.newsletter.CreateRecipientInput\x1a(.eolymp.newsletter.CreateRecipientOutput\"]\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02%\"#/campaigns/{campaign_id}/recipients\x12\xca\x01\n\x0fImportRecipient\x12\'.eolymp.newsletter.ImportRecipientInput\x1a(.eolymp.newsletter.ImportRecipientOutput\"d\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02,\"*/campaigns/{campaign_id}/recipients:import\x12\xd2\x01\n\x0f\x44\x65leteRecipient\x12\'.eolymp.newsletter.DeleteRecipientInput\x1a(.eolymp.newsletter.DeleteRecipientOutput\"l\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x34*2/campaigns/{campaign_id}/recipients/{recipient_id}\x12\xc0\x01\n\x0eListRecipients\x12&.eolymp.newsletter.ListRecipientsInput\x1a\'.eolymp.newsletter.ListRecipientsOutput\"]\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02%\x12#/campaigns/{campaign_id}/recipients\x12\xd8\x01\n\x11\x44\x65scribeRecipient\x12).eolymp.newsletter.DescribeRecipientInput\x1a*.eolymp.newsletter.DescribeRecipientOutput\"l\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1f\x8a\xe3\n\x1bnewsletter:newsletter:write\x82\xd3\xe4\x93\x02\x34\x12\x32/campaigns/{campaign_id}/recipients/{recipient_id}B7Z5github.com/eolymp/go-sdk/eolymp/newsletter;newsletterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.newsletter.campaign_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/newsletter;newsletter'
  _globals['_TESTCAMPAIGNINPUT_PARAMETERSENTRY']._loaded_options = None
  _globals['_TESTCAMPAIGNINPUT_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_CREATERECIPIENTINPUT_PARAMETERSENTRY']._loaded_options = None
  _globals['_CREATERECIPIENTINPUT_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_IMPORTRECIPIENTINPUT_PARAMETERSENTRY']._loaded_options = None
  _globals['_IMPORTRECIPIENTINPUT_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['CreateCampaign']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['CreateCampaign']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\003\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002\014\"\n/campaigns'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['UpdateCampaign']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['UpdateCampaign']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\005\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002\032\032\030/campaigns/{campaign_id}'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['DeleteCampaign']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['DeleteCampaign']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002\032*\030/campaigns/{campaign_id}'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['DescribeCampaign']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['DescribeCampaign']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002\032\022\030/campaigns/{campaign_id}'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['ListCampaigns']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['ListCampaigns']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\014\022\n/campaigns'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['TestCampaign']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['TestCampaign']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\002\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002\037\"\035/campaigns/{campaign_id}/test'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['SendCampaign']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['SendCampaign']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\002\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002\037\"\035/campaigns/{campaign_id}/send'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['TranslateCampaign']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['TranslateCampaign']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\002\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002$\"\"/campaigns/{campaign_id}/translate'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['CreateTranslation']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['CreateTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002\'\"%/campaigns/{campaign_id}/translations'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['UpdateTranslation']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['UpdateTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\0028\0326/campaigns/{campaign_id}/translations/{translation_id}'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['DeleteTranslation']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['DeleteTranslation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\0028*6/campaigns/{campaign_id}/translations/{translation_id}'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['DescribeTranslation']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['DescribeTranslation']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\343\n\036\212\343\n\032newsletter:newsletter:read\202\323\344\223\0028\0226/campaigns/{campaign_id}/translations/{translation_id}'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['ListTranslations']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['ListTranslations']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\036\212\343\n\032newsletter:newsletter:read\202\323\344\223\002\'\022%/campaigns/{campaign_id}/translations'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['CreateRecipient']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['CreateRecipient']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002%\"#/campaigns/{campaign_id}/recipients'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['ImportRecipient']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['ImportRecipient']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002,\"*/campaigns/{campaign_id}/recipients:import'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['DeleteRecipient']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['DeleteRecipient']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\0024*2/campaigns/{campaign_id}/recipients/{recipient_id}'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['ListRecipients']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['ListRecipients']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\002%\022#/campaigns/{campaign_id}/recipients'
  _globals['_CAMPAIGNSERVICE'].methods_by_name['DescribeRecipient']._loaded_options = None
  _globals['_CAMPAIGNSERVICE'].methods_by_name['DescribeRecipient']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\037\212\343\n\033newsletter:newsletter:write\202\323\344\223\0024\0222/campaigns/{campaign_id}/recipients/{recipient_id}'
  _globals['_CREATECAMPAIGNINPUT']._serialized_start=300
  _globals['_CREATECAMPAIGNINPUT']._serialized_end=368
  _globals['_CREATECAMPAIGNOUTPUT']._serialized_start=370
  _globals['_CREATECAMPAIGNOUTPUT']._serialized_end=413
  _globals['_UPDATECAMPAIGNINPUT']._serialized_start=416
  _globals['_UPDATECAMPAIGNINPUT']._serialized_end=555
  _globals['_UPDATECAMPAIGNOUTPUT']._serialized_start=557
  _globals['_UPDATECAMPAIGNOUTPUT']._serialized_end=579
  _globals['_DELETECAMPAIGNINPUT']._serialized_start=581
  _globals['_DELETECAMPAIGNINPUT']._serialized_end=623
  _globals['_DELETECAMPAIGNOUTPUT']._serialized_start=625
  _globals['_DELETECAMPAIGNOUTPUT']._serialized_end=647
  _globals['_DESCRIBECAMPAIGNINPUT']._serialized_start=649
  _globals['_DESCRIBECAMPAIGNINPUT']._serialized_end=744
  _globals['_DESCRIBECAMPAIGNOUTPUT']._serialized_start=746
  _globals['_DESCRIBECAMPAIGNOUTPUT']._serialized_end=817
  _globals['_LISTCAMPAIGNSINPUT']._serialized_start=820
  _globals['_LISTCAMPAIGNSINPUT']._serialized_end=1245
  _globals['_LISTCAMPAIGNSINPUT_FILTER']._serialized_start=1121
  _globals['_LISTCAMPAIGNSINPUT_FILTER']._serialized_end=1221
  _globals['_LISTCAMPAIGNSINPUT_SORT']._serialized_start=1223
  _globals['_LISTCAMPAIGNSINPUT_SORT']._serialized_end=1245
  _globals['_LISTCAMPAIGNSOUTPUT']._serialized_start=1247
  _globals['_LISTCAMPAIGNSOUTPUT']._serialized_end=1327
  _globals['_TESTCAMPAIGNINPUT']._serialized_start=1330
  _globals['_TESTCAMPAIGNINPUT']._serialized_end=1545
  _globals['_TESTCAMPAIGNINPUT_PARAMETERSENTRY']._serialized_start=1496
  _globals['_TESTCAMPAIGNINPUT_PARAMETERSENTRY']._serialized_end=1545
  _globals['_TESTCAMPAIGNOUTPUT']._serialized_start=1547
  _globals['_TESTCAMPAIGNOUTPUT']._serialized_end=1567
  _globals['_SENDCAMPAIGNINPUT']._serialized_start=1569
  _globals['_SENDCAMPAIGNINPUT']._serialized_end=1631
  _globals['_SENDCAMPAIGNOUTPUT']._serialized_start=1633
  _globals['_SENDCAMPAIGNOUTPUT']._serialized_end=1653
  _globals['_TRANSLATECAMPAIGNINPUT']._serialized_start=1656
  _globals['_TRANSLATECAMPAIGNINPUT']._serialized_end=1784
  _globals['_TRANSLATECAMPAIGNOUTPUT']._serialized_start=1786
  _globals['_TRANSLATECAMPAIGNOUTPUT']._serialized_end=1827
  _globals['_CREATETRANSLATIONINPUT']._serialized_start=1829
  _globals['_CREATETRANSLATIONINPUT']._serialized_end=1936
  _globals['_CREATETRANSLATIONOUTPUT']._serialized_start=1938
  _globals['_CREATETRANSLATIONOUTPUT']._serialized_end=1987
  _globals['_UPDATETRANSLATIONINPUT']._serialized_start=1990
  _globals['_UPDATETRANSLATIONINPUT']._serialized_end=2171
  _globals['_UPDATETRANSLATIONOUTPUT']._serialized_start=2173
  _globals['_UPDATETRANSLATIONOUTPUT']._serialized_end=2198
  _globals['_DELETETRANSLATIONINPUT']._serialized_start=2200
  _globals['_DELETETRANSLATIONINPUT']._serialized_end=2269
  _globals['_DELETETRANSLATIONOUTPUT']._serialized_start=2271
  _globals['_DELETETRANSLATIONOUTPUT']._serialized_end=2296
  _globals['_DESCRIBETRANSLATIONINPUT']._serialized_start=2298
  _globals['_DESCRIBETRANSLATIONINPUT']._serialized_end=2369
  _globals['_DESCRIBETRANSLATIONOUTPUT']._serialized_start=2371
  _globals['_DESCRIBETRANSLATIONOUTPUT']._serialized_end=2460
  _globals['_LISTTRANSLATIONSINPUT']._serialized_start=2463
  _globals['_LISTTRANSLATIONSINPUT']._serialized_end=2707
  _globals['_LISTTRANSLATIONSINPUT_FILTER']._serialized_start=2605
  _globals['_LISTTRANSLATIONSINPUT_FILTER']._serialized_end=2707
  _globals['_LISTTRANSLATIONSOUTPUT']._serialized_start=2709
  _globals['_LISTTRANSLATIONSOUTPUT']._serialized_end=2804
  _globals['_CREATERECIPIENTINPUT']._serialized_start=2807
  _globals['_CREATERECIPIENTINPUT']._serialized_end=2997
  _globals['_CREATERECIPIENTINPUT_PARAMETERSENTRY']._serialized_start=1496
  _globals['_CREATERECIPIENTINPUT_PARAMETERSENTRY']._serialized_end=1545
  _globals['_CREATERECIPIENTOUTPUT']._serialized_start=2999
  _globals['_CREATERECIPIENTOUTPUT']._serialized_end=3044
  _globals['_IMPORTRECIPIENTINPUT']._serialized_start=3047
  _globals['_IMPORTRECIPIENTINPUT']._serialized_end=3293
  _globals['_IMPORTRECIPIENTINPUT_PARAMETERSENTRY']._serialized_start=1496
  _globals['_IMPORTRECIPIENTINPUT_PARAMETERSENTRY']._serialized_end=1545
  _globals['_IMPORTRECIPIENTOUTPUT']._serialized_start=3295
  _globals['_IMPORTRECIPIENTOUTPUT']._serialized_end=3318
  _globals['_DELETERECIPIENTINPUT']._serialized_start=3320
  _globals['_DELETERECIPIENTINPUT']._serialized_end=3385
  _globals['_DELETERECIPIENTOUTPUT']._serialized_start=3387
  _globals['_DELETERECIPIENTOUTPUT']._serialized_end=3410
  _globals['_LISTRECIPIENTSINPUT']._serialized_start=3413
  _globals['_LISTRECIPIENTSINPUT']._serialized_end=3705
  _globals['_LISTRECIPIENTSINPUT_FILTER']._serialized_start=3552
  _globals['_LISTRECIPIENTSINPUT_FILTER']._serialized_end=3705
  _globals['_LISTRECIPIENTSOUTPUT']._serialized_start=3707
  _globals['_LISTRECIPIENTSOUTPUT']._serialized_end=3789
  _globals['_DESCRIBERECIPIENTINPUT']._serialized_start=3791
  _globals['_DESCRIBERECIPIENTINPUT']._serialized_end=3858
  _globals['_DESCRIBERECIPIENTOUTPUT']._serialized_start=3860
  _globals['_DESCRIBERECIPIENTOUTPUT']._serialized_end=3934
  _globals['_CAMPAIGNSERVICE']._serialized_start=3937
  _globals['_CAMPAIGNSERVICE']._serialized_end=7462
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/worker/worker_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/worker/worker_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from eolymp.worker import worker_job_pb2 as eolymp_dot_worker_dot_worker__job__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/worker/worker_service.proto\x12\reolymp.worker\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1e\x65olymp/worker/worker_job.proto\"2\n\x0fJobTriggerEvent\x12\x1f\n\x03job\x18\x01 \x01(\x0b\x32\x12.eolymp.worker.Job\"\x88\x01\n\x0e\x43reateJobInput\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x39\n\x06inputs\x18\x02 \x03(\x0b\x32).eolymp.worker.CreateJobInput.InputsEntry\x1a-\n\x0bInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"!\n\x0f\x43reateJobOutput\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\"\n\x10\x44\x65scribeJobInput\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"4\n\x11\x44\x65scribeJobOutput\x12\x1f\n\x03job\x18\x01 \x01(\x0b\x32\x12.eolymp.worker.Job\"\xfc\x01\n\rListJobsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x34\n\x07\x66ilters\x18( \x01(\x0b\x32#.eolymp.worker.ListJobsInput.Filter\x1a\x96\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12.\n\x04type\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x06status\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"B\n\x0eListJobsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12!\n\x05items\x18\x02 \x03(\x0b\x32\x12.eolymp.worker.Job2\xec\x02\n\rWorkerService\x12L\n\tCreateJob\x12\x1d.eolymp.worker.CreateJobInput\x1a\x1e.eolymp.worker.CreateJobOutput\"\x00\x12\x8e\x01\n\x0b\x44\x65scribeJob\x12\x1f.eolymp.worker.DescribeJobInput\x1a .eolymp.worker.DescribeJobOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x13\x8a\xe3\n\x0fworker:job:read\x82\xd3\xe4\x93\x02\x10\x12\x0e/jobs/{job_id}\x12|\n\x08ListJobs\x12\x1c.eolymp.worker.ListJobsInput\x1a\x1d.eolymp.worker.ListJobsOutput\"3\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x13\x8a\xe3\n\x0fworker:job:read\x82\xd3\xe4\x93\x02\x07\x12\x05/jobsB/Z-github.com/eolymp/go-sdk/eolymp/worker;workerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.worker.worker_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/worker;worker'
  _globals['_CREATEJOBINPUT_INPUTSENTRY']._loaded_options = None
  _globals['_CREATEJOBINPUT_INPUTSENTRY']._serialized_options = b'8\001'
  _globals['_WORKERSERVICE'].methods_by_name['DescribeJob']._loaded_options = None
  _globals['_WORKERSERVICE'].methods_by_name['DescribeJob']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\023\212\343\n\017worker:job:read\202\323\344\223\002\020\022\016/jobs/{job_id}'
  _globals['_WORKERSERVICE'].methods_by_name['ListJobs']._loaded_options = None
  _globals['_WORKERSERVICE'].methods_by_name['ListJobs']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\023\212\343\n\017worker:job:read\202\323\344\223\002\007\022\005/jobs'
  _globals['_JOBTRIGGEREVENT']._serialized_start=219
  _globals['_JOBTRIGGEREVENT']._serialized_end=269
  _globals['_CREATEJOBINPUT']._serialized_start=272
  _globals['_CREATEJOBINPUT']._serialized_end=408
  _globals['_CREATEJOBINPUT_INPUTSENTRY']._serialized_start=363
  _globals['_CREATEJOBINPUT_INPUTSENTRY']._serialized_end=408
  _globals['_CREATEJOBOUTPUT']._serialized_start=410
  _globals['_CREATEJOBOUTPUT']._serialized_end=443
  _globals['_DESCRIBEJOBINPUT']._serialized_start=445
  _globals['_DESCRIBEJOBINPUT']._serialized_end=479
  _globals['_DESCRIBEJOBOUTPUT']._serialized_start=481
  _globals['_DESCRIBEJOBOUTPUT']._serialized_end=533
  _globals['_LISTJOBSINPUT']._serialized_start=536
  _globals['_LISTJOBSINPUT']._serialized_end=788
  _globals['_LISTJOBSINPUT_FILTER']._serialized_start=638
  _globals['_LISTJOBSINPUT_FILTER']._serialized_end=788
  _globals['_LISTJOBSOUTPUT']._serialized_start=790
  _globals['_LISTJOBSOUTPUT']._serialized_end=856
  _globals['_WORKERSERVICE']._serialized_start=859
  _globals['_WORKERSERVICE']._serialized_end=1223
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/discussion/message_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/discussion/message_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.discussion import message_pb2 as eolymp_dot_discussion_dot_message__pb2
from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'eolymp/discussion/message_service.proto\x12\x11\x65olymp.discussion\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1f\x65olymp/discussion/message.proto\x1a\x18\x65olymp/ecm/content.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8b\x01\n\x13MessageChangedEvent\x12\r\n\x05scope\x18\n \x01(\t\x12*\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x1a.eolymp.discussion.Message\x12)\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x1a.eolymp.discussion.Message\x12\x0e\n\x06reason\x18\x03 \x01(\t\"l\n\x14\x44\x65scribeMessageInput\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12\x0e\n\x06render\x18\x02 \x01(\x08\x12\x30\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32 .eolymp.discussion.Message.Extra\"D\n\x15\x44\x65scribeMessageOutput\x12+\n\x07message\x18\x01 \x01(\x0b\x32\x1a.eolymp.discussion.Message\"\xe5\x05\n\x11ListMessagesInput\x12\x0e\n\x06render\x18\x01 \x01(\x08\x12\r\n\x05\x61\x66ter\x18\n \x01(\t\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x04sort\x18\x32 \x01(\x0e\x32-.eolymp.discussion.ListMessagesInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12<\n\x07\x66ilters\x18( \x01(\x0b\x32+.eolymp.discussion.ListMessagesInput.Filter\x12\x30\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32 .eolymp.discussion.Message.Extra\x1a\x80\x03\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x08reply_to\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\x04 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tthread_id\x18\x05 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x33\n\nvote_count\x18\x06 \x03(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\x12\x34\n\x0breply_count\x18\x07 \x03(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\x12\x38\n\tposted_at\x18\x08 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\"G\n\x08Sortable\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\r\n\tPOSTED_AT\x10\x01\x12\x0e\n\nVOTE_COUNT\x10\x02\x12\x0f\n\x0bREPLY_COUNT\x10\x03\"N\n\x12ListMessagesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12)\n\x05items\x18\x02 \x03(\x0b\x32\x1a.eolymp.discussion.Message\"Q\n\x10PostMessageInput\x12+\n\x07message\x18\x01 \x01(\x0b\x32\x1a.eolymp.discussion.Message\x12\x10\n\x08reply_to\x18\x02 \x01(\t\"\'\n\x11PostMessageOutput\x12\x12\n\nmessage_id\x18\x01 \x01(\t\"U\n\x12UpdateMessageInput\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12+\n\x07message\x18\x02 \x01(\x0b\x32\x1a.eolymp.discussion.Message\"\x15\n\x13UpdateMessageOutput\"8\n\x12\x44\x65leteMessageInput\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"\x15\n\x13\x44\x65leteMessageOutput\"4\n\x10VoteMessageInput\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12\x0c\n\x04vote\x18\x02 \x01(\x05\"\'\n\x11VoteMessageOutput\x12\x12\n\nvote_count\x18\x01 \x01(\x05\"-\n\x17ListMessageChangesInput\x12\x12\n\nmessage_id\x18\x01 \x01(\t\"\xd0\x01\n\x18ListMessageChangesOutput\x12\x43\n\x07history\x18\x01 \x03(\x0b\x32\x32.eolymp.discussion.ListMessageChangesOutput.Record\x1ao\n\x06Record\x12\x10\n\x08revision\x18\x01 \x01(\x05\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\x07message\x18\x03 \x01(\x0b\x32\x13.eolymp.ecm.Content2\xd7\t\n\x0eMessageService\x12\xb3\x01\n\x0f\x44\x65scribeMessage\x12\'.eolymp.discussion.DescribeMessageInput\x1a(.eolymp.discussion.DescribeMessageOutput\"M\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xe3\n\x1b\x8a\xe3\n\x17\x64iscussion:message:read\x82\xd3\xe4\x93\x02\x18\x12\x16/messages/{message_id}\x12\x9c\x01\n\x0cListMessages\x12$.eolymp.discussion.ListMessagesInput\x1a%.eolymp.discussion.ListMessagesOutput\"?\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x1b\x8a\xe3\n\x17\x64iscussion:message:read\x82\xd3\xe4\x93\x02\x0b\x12\t/messages\x12\x9a\x01\n\x0bPostMessage\x12#.eolymp.discussion.PostMessageInput\x1a$.eolymp.discussion.PostMessageOutput\"@\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\x82\xd3\xe4\x93\x02\x0b\"\t/messages\x12\xad\x01\n\rUpdateMessage\x12%.eolymp.discussion.UpdateMessageInput\x1a&.eolymp.discussion.UpdateMessageOutput\"M\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\x82\xd3\xe4\x93\x02\x18\x1a\x16/messages/{message_id}\x12\xad\x01\n\rDeleteMessage\x12%.eolymp.discussion.DeleteMessageInput\x1a&.eolymp.discussion.DeleteMessageOutput\"M\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\x82\xd3\xe4\x93\x02\x18*\x16/messages/{message_id}\x12\xac\x01\n\x0bVoteMessage\x12#.eolymp.discussion.VoteMessageInput\x1a$.eolymp.discussion.VoteMessageOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x1c\x8a\xe3\n\x18\x64iscussion:message:write\x82\xd3\xe4\x93\x02\x1d\"\x1b/messages/{message_id}/vote\x12\xc3\x01\n\x12ListMessageChanges\x12*.eolymp.discussion.ListMessageChangesInput\x1a+.eolymp.discussion.ListMessageChangesOutput\"T\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x1b\x8a\xe3\n\x17\x64iscussion:message:read\x82\xd3\xe4\x93\x02 \x12\x1e/messages/{message_id}/changesB7Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.message_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _globals['_MESSAGESERVICE'].methods_by_name['DescribeMessage']._loaded_options = None
  _globals['_MESSAGESERVICE'].methods_by_name['DescribeMessage']._serialized_options = b'\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\343\n\033\212\343\n\027discussion:message:read\202\323\344\223\002\030\022\026/messages/{message_id}'
  _globals['_MESSAGESERVICE'].methods_by_name['ListMessages']._loaded_options = None
  _globals['_MESSAGESERVICE'].methods_by_name['ListMessages']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\033\212\343\n\027discussion:message:read\202\323\344\223\002\013\022\t/messages'
  _globals['_MESSAGESERVICE'].methods_by_name['PostMessage']._loaded_options = None
  _globals['_MESSAGESERVICE'].methods_by_name['PostMessage']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\034\212\343\n\030discussion:message:write\202\323\344\223\002\013\"\t/messages'
  _globals['_MESSAGESERVICE'].methods_by_name['UpdateMessage']._loaded_options = None
  _globals['_MESSAGESERVICE'].methods_by_name['UpdateMessage']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\034\212\343\n\030discussion:message:write\202\323\344\223\002\030\032\026/messages/{message_id}'
  _globals['_MESSAGESERVICE'].methods_by_name['DeleteMessage']._loaded_options = None
  _globals['_MESSAGESERVICE'].methods_by_name['DeleteMessage']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\034\212\343\n\030discussion:message:write\202\323\344\223\002\030*\026/messages/{message_id}'
  _globals['_MESSAGESERVICE'].methods_by_name['VoteMessage']._loaded_options = None
  _globals['_MESSAGESERVICE'].methods_by_name['VoteMessage']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\034\212\343\n\030discussion:message:write\202\323\344\223\002\035\"\033/messages/{message_id}/vote'
  _globals['_MESSAGESERVICE'].methods_by_name['ListMessageChanges']._loaded_options = None
  _globals['_MESSAGESERVICE'].methods_by_name['ListMessageChanges']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\033\212\343\n\027discussion:message:read\202\323\344\223\002 \022\036/messages/{message_id}/changes'
  _globals['_MESSAGECHANGEDEVENT']._serialized_start=323
  _globals['_MESSAGECHANGEDEVENT']._serialized_end=462
  _globals['_DESCRIBEMESSAGEINPUT']._serialized_start=464
  _globals['_DESCRIBEMESSAGEINPUT']._serialized_end=572
  _globals['_DESCRIBEMESSAGEOUTPUT']._serialized_start=574
  _globals['_DESCRIBEMESSAGEOUTPUT']._serialized_end=642
  _globals['_LISTMESSAGESINPUT']._serialized_start=645
  _globals['_LISTMESSAGESINPUT']._serialized_end=1386
  _globals['_LISTMESSAGESINPUT_FILTER']._serialized_start=929
  _globals['_LISTMESSAGESINPUT_FILTER']._serialized_end=1313
  _globals['_LISTMESSAGESINPUT_SORTABLE']._serialized_start=1315
  _globals['_LISTMESSAGESINPUT_SORTABLE']._serialized_end=1386
  _globals['_LISTMESSAGESOUTPUT']._serialized_start=1388
  _globals['_LISTMESSAGESOUTPUT']._serialized_end=1466
  _globals['_POSTMESSAGEINPUT']._serialized_start=1468
  _globals['_POSTMESSAGEINPUT']._serialized_end=1549
  _globals['_POSTMESSAGEOUTPUT']._serialized_start=1551
  _globals['_POSTMESSAGEOUTPUT']._serialized_end=1590
  _globals['_UPDATEMESSAGEINPUT']._serialized_start=1592
  _globals['_UPDATEMESSAGEINPUT']._serialized_end=1677
  _globals['_UPDATEMESSAGEOUTPUT']._serialized_start=1679
  _globals['_UPDATEMESSAGEOUTPUT']._serialized_end=1700
  _globals['_DELETEMESSAGEINPUT']._serialized_start=1702
  _globals['_DELETEMESSAGEINPUT']._serialized_end=1758
  _globals['_DELETEMESSAGEOUTPUT']._serialized_start=1760
  _globals['_DELETEMESSAGEOUTPUT']._serialized_end=1781
  _globals['_VOTEMESSAGEINPUT']._serialized_start=1783
  _globals['_VOTEMESSAGEINPUT']._serialized_end=1835
  _globals['_VOTEMESSAGEOUTPUT']._serialized_start=1837
  _globals['_VOTEMESSAGEOUTPUT']._serialized_end=1876
  _globals['_LISTMESSAGECHANGESINPUT']._serialized_start=1878
  _globals['_LISTMESSAGECHANGESINPUT']._serialized_end=1923
  _globals['_LISTMESSAGECHANGESOUTPUT']._serialized_start=1926
  _globals['_LISTMESSAGECHANGESOUTPUT']._serialized_end=2134
  _globals['_LISTMESSAGECHANGESOUTPUT_RECORD']._serialized_start=2023
  _globals['_LISTMESSAGECHANGESOUTPUT_RECORD']._serialized_end=2134
  _globals['_MESSAGESERVICE']._serialized_start=2137
  _globals['_MESSAGESERVICE']._serialized_end=3376
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/testing_testset.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'eolymp/atlas/testing_testset.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.atlas import testing_feedback_pb2 as eolymp_dot_atlas_dot_testing__feedback__pb2
from eolymp.atlas import testing_scoring_pb2 as eolymp_dot_atlas_dot_testing__scoring__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/atlas/testing_testset.proto\x12\x0c\x65olymp.atlas\x1a#eolymp/atlas/testing_feedback.proto\x1a\"eolymp/atlas/testing_scoring.proto\"\x9f\x03\n\x07Testset\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x04 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\r\x12\x12\n\ntime_limit\x18\n \x01(\r\x12\x11\n\tcpu_limit\x18\r \x01(\r\x12\x14\n\x0cmemory_limit\x18\x0b \x01(\x04\x12\x17\n\x0f\x66ile_size_limit\x18\x0c \x01(\x04\x12\x14\n\x0c\x64\x65pendencies\x18\x14 \x03(\r\x12=\n\x0f\x64\x65pendency_mode\x18\x15 \x01(\x0e\x32$.eolymp.atlas.Testset.DependencyMode\x12/\n\x0cscoring_mode\x18\x1e \x01(\x0e\x32\x19.eolymp.atlas.ScoringMode\x12\x35\n\x0f\x66\x65\x65\x64\x62\x61\x63k_policy\x18( \x01(\x0e\x32\x1c.eolymp.atlas.FeedbackPolicy\"R\n\x0e\x44\x65pendencyMode\x12\x1b\n\x17UNKNOWN_DEPENDENCY_MODE\x10\x00\x12\x12\n\x0e\x46ULLY_ACCEPTED\x10\x01\x12\x0f\n\x0b\x46IRST_POINT\x10\x02\x42-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.testing_testset_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_TESTSET']._serialized_start=126
  _globals['_TESTSET']._serialized_end=541
  _globals['_TESTSET_DEPENDENCYMODE']._serialized_start=459
  _globals['_TESTSET_DEPENDENCYMODE']._serialized_end=541
# @@protoc_insertion_point(module_scope)



from eolymp.executor import file_pb2 as _file_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Interactor(_message.Message):
    __slots__ = ("type", "runtime", "source_url", "secret", "files")
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        NONE: _ClassVar[Interactor.Type]
        PROGRAM: _ClassVar[Interactor.Type]
    NONE: Interactor.Type
    PROGRAM: Interactor.Type
    TYPE_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_FIELD_NUMBER: _ClassVar[int]
    SOURCE_URL_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    FILES_FIELD_NUMBER: _ClassVar[int]
    type: Interactor.Type
    runtime: str
    source_url: str
    secret: bool
    files: _containers.RepeatedCompositeFieldContainer[_file_pb2.File]
    def __init__(self, type: _Optional[_Union[Interactor.Type, str]] = ..., runtime: _Optional[str] = ..., source_url: _Optional[str] = ..., secret: bool = ..., files: _Optional[_Iterable[_Union[_file_pb2.File, _Mapping]]] = ...) -> None: ...
